# spec file for php-pecl-gnupg
#
# SPDX-FileCopyrightText:  Copyright 2012-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package             php-pecl-gnupg
%else
%global _root_bindir     %{_bindir}
%endif

%if 0%{?fedora} >= 41
# TODO needs investigation
# fails in mock, succeeds in local build
%bcond_with              tests
%else
%bcond_without           tests
%endif
# to run test with GnuPG v1 instead of GnuPG v2
%bcond_with              gpg1

%global pecl_name        gnupg
%global with_zts         0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name         40-%{pecl_name}.ini
%global upstream_version 1.5.3
#global upstream_prever  RC2
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:      Wrapper around the gpgme library
Name:         %{?scl_prefix}php-pecl-gnupg
Version:      %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:      2%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}

License:      BSD-2-Clause
URL:          https://pecl.php.net/package/gnupg
Source0:      https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

Patch0:       57.patch

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel
BuildRequires: %{?scl_prefix}php-pear
BuildRequires: gpgme-devel
BuildRequires: gnupg

Requires:     %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:     %{?scl_prefix}php(api) = %{php_core_api}
%if %{with gpg1}
Requires:     gnupg1
%endif
Requires:     gnupg

Provides:     %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:     %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This module allows you to interact with gnupg. 

Documentation : http://www.php.net/gnupg

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep 
%setup -c -q

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

# Create configuration file
cat >%{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF

cd %{sources}
%if "%{php_version}" > "7.0"
%patch -P0 -p1
%endif

# Check extension version
extver=$(sed -n '/#define PHP_GNUPG_VERSION/{s/.* "//;s/".*$//;p}' php_gnupg.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Build ZTS extension if ZTS devel available (fedora >= 17)
mkdir ZTS
%endif

%if %{with gpg1}
%{_root_bindir}/gpg1 --version
%else
%{_root_bindir}/gpg --version
%endif


%build
%{?dtsenable}

export PHP_RPATH=no
export CFLAGS="$RPM_OPT_FLAGS -D_FILE_OFFSET_BITS=64"

peclbuild() {
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=${1}

%make_build
}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
peclbuild %{__phpconfig}

%if %{with_zts}
cd ../ZTS
peclbuild %{__ztsphpconfig}
%endif


%install
%{?dtsenable}

%make_install -C NTS

# Drop in the bit of configuration
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}
unset GPG_AGENT_INFO
%if %{with gpg1}
export GNUPGFILENAME=%{_root_bindir}/gpg1
%endif

: Check if build NTS extension can be loaded
%{__php} -n -q \
    -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Run upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php \
    -n -q \
    -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --show-diff
%endif

%if %{with_zts}
: Check if build ZTS extension can be loaded
%{__ztsphp} -n -q \
    -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Jul 17 2025 Remi Collet <remi@remirepo.net> - 1.5.3-2
- add fix for PHP 8.5.0alpha2 using patch from
  https://github.com/php-gnupg/php-gnupg/pull/57

* Tue Jun  3 2025 Remi Collet <remi@remirepo.net> - 1.5.3-1
- update to 1.5.3
- drop patch merged upstream

* Tue Apr  8 2025 Remi Collet <remi@remirepo.net> - 1.5.2-1
- update to 1.5.2
- re-license spec file to CECILL-2.1
- open https://github.com/php-gnupg/php-gnupg/pull/52 file missing in archive
- open https://github.com/php-gnupg/php-gnupg/pull/53 fix tests with PHP 5

* Tue Oct  1 2024 Remi Collet <remi@remirepo.net> - 1.5.1-4
- ignore test suite on F41

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 1.5.1-3
- rebuild for PHP 8.3.0RC1

* Fri Jul 21 2023 Remi Collet <remi@remirepo.net> - 1.5.1-2
- build out of sources tree

* Sat Jan  1 2022 Remi Collet <remi@remirepo.net> - 1.5.1-1
- update to 1.5.1
- drop patch merged upstream

* Thu Sep  9 2021 Remi Collet <remi@remirepo.net> - 1.5.0-3
- improve patch for PHP 8.1 from
  https://github.com/php-gnupg/php-gnupg/pull/35
  https://github.com/bukka/phpc/pull/3

* Thu Sep  9 2021 Remi Collet <remi@remirepo.net> - 1.5.0-2
- add patch for PHP 8.1 from
  https://github.com/php-gnupg/php-gnupg/pull/35

* Mon Apr 12 2021 Remi Collet <remi@remirepo.net> - 1.5.0-1
- Update to 1.5.0

* Mon Mar  8 2021 Remi Collet <remi@remirepo.net> - 1.5.0~RC2-1
- Update to 1.5.0RC2
- drop patch merged upstream

* Mon Feb 15 2021 Remi Collet <remi@remirepo.net> - 1.5.0~RC1-1
- Update to 1.5.0RC1
- open https://github.com/php-gnupg/php-gnupg/pull/25
  missing files in pecl archive
- open https://github.com/php-gnupg/php-gnupg/pull/26
  also cleanup socket files
- open https://github.com/php-gnupg/php-gnupg/pull/27
  fix build with old libgpgme 1.3
- use gnupg version 2 (Fedora and EL-8)

* Tue Feb  2 2021 Remi Collet <remi@remirepo.net> - 1.4.0-10
- EL-7 rebuild

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.4.0-9
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.4.0-8
- rebuild for 7.4.0beta1

* Wed Dec 12 2018 Remi Collet <remi@remirepo.net> - 1.4.0-7
- cleanup for EL-8

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.4.0-6
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.4.0-5
- rebuld for 7.3.0alpha4 new ABI

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.4.0-4
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-2
- rebuild for PHP 7.1 new API version

* Thu Sep  1 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-1
- update to 1.4.0 (stable)

* Mon Jul 25 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-0.3.RC2
- update to 1.4.0RC2 (beta)

* Fri Jun 17 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-0.2.RC1
- always use gnupg < 2

* Thu Jun 16 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-0.1.RC1
- update to 1.4.0RC1 (beta)

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 1.3.6-2
- adapt for F24

* Thu Feb 12 2015 Remi Collet <remi@fedoraproject.org> - 1.3.6-1
- Update to 1.3.6
- don't install test suite
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.3.3-5.1
- Fedora 21 SCL mass rebuild

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 1.3.3-5
- improve SCL build

* Wed Apr 16 2014 Remi Collet <remi@fedoraproject.org> - 1.3.3-4
- add numerical prefix to extension configuration file

* Wed Mar 26 2014 Remi Collet <remi@fedoraproject.org> - 1.3.3-3
- allow SCL build

* Mon Mar 17 2014 Remi Collet <remi@fedoraproject.org> - 1.3.3-2
- cleanups
- make ZTS build optional
- install doc in pecl_docdir
- install tests in pecl_testdir

* Wed Jul 17 2013 Remi Collet <remi@fedoraproject.org> - 1.3.3-1
- update to 1.3.3

* Sun Jun 30 2013 Remi Collet <remi@fedoraproject.org> - 1.3.2-4
- ignore test result

* Fri Nov 30 2012 Remi Collet <remi@fedoraproject.org> - 1.3.2-3.1
- also provides php-gnupg + cleanups

* Sun May 06 2012 Remi Collet <remi@fedoraproject.org> - 1.3.2-3
- improve patch

* Sat Jan 28 2012 Remi Collet <remi@fedoraproject.org> - 1.3.2-2
- build against PHP 5.4

* Sat Jan 28 2012 Remi Collet <remi@fedoraproject.org> - 1.3.2-1
- Initial RPM
- open upstream bugs
  https://bugs.php.net/60913 - test suite fails
  https://bugs.php.net/60914 - bad version
  https://bugs.php.net/60915 - php 5.4 build fails
  https://bugs.php.net/60916 - force use of /usr/bin/gpg
